<?php
/**
 * The header for custom functions
 *
 * @link http://www.wp3layouts.com
 *
 * @package Fashiona
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function fashiona_wp3_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'fashiona_wp3_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function fashiona_wp3_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'fashiona_wp3_pingback_header' );


function fashiona_wp3_logo_cb(){ 	
	$wp3_tagline 	= get_theme_mod('fashiona_wp3_hide_title_tagline', 1);
	?>
	<div class="header-bottom">
		<div class="container">
			<div class="logo wow fadeInDown"  data-wow-duration=".8s" data-wow-delay=".2s">
			 <?php if( has_custom_logo() ) :?>
			 
			 <?php echo get_custom_logo(); ?>

				<?php if( $wp3_tagline == 1 ): ?>
					<p class="site-description">
						<?php bloginfo( 'description' ); ?>
					</p>
				<?php endif; ?>
			<?php else: ?>
				<h1>
					<a href="<?php echo esc_url( home_url() ); ?>"><?php bloginfo( 'name' ); ?></a>
				</h1>
				<?php if( $wp3_tagline == 1 ): ?>
					<p class="site-description">
						<?php bloginfo( 'description' ); ?>
					</p>
				<?php endif; ?>
			<?php endif; ?>
			</div>
		</div>
	</div>
	<?php 

} 
add_action( 'fashiona_wp3_logo', 'fashiona_wp3_logo_cb' );


function fashiona_wp3_social_cb(){ 	
    $wp3_social_twit 	= get_theme_mod('fashiona_wp3_social_twitter', '');
	$wp3_social_fb 		= get_theme_mod('fashiona_wp3_social_facebook', '');
	$wp3_social_inst 	= get_theme_mod('fashiona_wp3_social_instagram', '');
	$wp3_social_gplus 	= get_theme_mod('fashiona_wp3_social_gplus', '');
	$wp3_social_pint 	= get_theme_mod('fashiona_wp3_social_pinterest', '');
	$wp3_social_youtu 	= get_theme_mod('fashiona_wp3_social_youtube', '');
	$wp3_social_linkd 	= get_theme_mod('fashiona_wp3_social_linkedin', '');
	$wp3_social_feed 	= get_theme_mod('fashiona_wp3_social_feed', '');
	
if($wp3_social_twit || $wp3_social_fb || $wp3_social_inst || $wp3_social_gplus || $wp3_social_pint || $wp3_social_youtu || $wp3_social_linkd || $wp3_social_feed ):
	?>
	<div class="navbar-right social-icons wow fadeInRight animated animated" data-wow-delay=".5s" style="visibility: visible; animation-delay: 0.5s; animation-name: fadeInRight;">
		<ul><?php if($wp3_social_fb) { ?>
			<li><a href="<?php echo esc_url($wp3_social_fb); ?>"  title="Facebook" target="_blank" class="facebook"><i class="fa fa-facebook" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_twit) { ?>
			<li><a href="<?php echo esc_url($wp3_social_twit); ?>" title="Twitter" target="_blank" class="twitter"><i class="fa fa-twitter" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_gplus) { ?>
			<li><a href="<?php echo esc_url($wp3_social_gplus); ?>" title="Google Plus" target="_blank" class="google-plus"><i class="fa fa-google-plus" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_linkd) { ?>
			<li><a href="<?php echo esc_url($wp3_social_linkd); ?>" title="Linkedin" target="_blank" class="linkedin"><i class="fa fa-linkedin" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_pint) { ?>
			<li><a href="<?php echo esc_url($wp3_social_pint); ?>" title="Pinterest" target="_blank" class="pinterest"><i class="fa fa-pinterest" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_inst) { ?>
			<li><a href="<?php echo esc_url($wp3_social_inst); ?>" title="Instagram" target="_blank" class="instagram"><i class="fa fa-instagram" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_youtu) { ?>
			<li><a href="<?php echo esc_url($wp3_social_youtu); ?>" title="YouTube" target="_blank" class="youtube"><i class="fa fa-youtube-play" aria-hidden="true"></i> </a></li>
					<?php } if($wp3_social_feed) { ?>
			<li><a href="<?php echo esc_url($wp3_social_feed); ?>" title="RSS Feed" target="_blank" class="feed"><i class="fa fa-rss" aria-hidden="true"></i> </a></li>
					<?php } ?>
		</ul>
	</div>
	<?php 
	endif; 
} 
add_action( 'fashiona_wp3_social', 'fashiona_wp3_social_cb' );

function fashiona_wp3_search_cb(){ 	
	$wp3_search_btn = get_theme_mod('fashiona_wp3_hide_search_button', 1);
	
	if( $wp3_search_btn == 1 ):
	?>
	<div class="search-right">
		<div class="header-search">
			<div class="search-button">
				<input class="search_box" type="checkbox" id="search_box">
				<label class="icon-search" data-featherlight="#mysearch" for="search_box"><span class="glyphicon glyphicon-search" aria-hidden="true"></span></label>
			</div>
		</div>
	</div>
	<?php 
	endif;
} 
add_action( 'fashiona_wp3_search', 'fashiona_wp3_search_cb' );

function fashiona_wp3_ft(){
	?>
	<div class="footer-section">
		<?php
		/**
		* Get the Footer Sidebars:
		**/
		get_sidebar( 'footer' );
		?>
		<div class="copyright wow fadeInDown"  data-wow-duration=".8s" data-wow-delay=".2s">
			<div class="container">
				<p class="copyright-info">
					<span class="wordpress">
						<?php if( get_theme_mod('fashiona_wp3_footer_copyright','') != '' ){ echo esc_attr( get_theme_mod('fashiona_wp3_footer_copyright') ); } else { ?>
						<?php printf( esc_html__( 'Proudly powered by %s', 'fashiona' ), '<a href="https://wordpress.org/" target="_blank">WordPress</a>' ); ?>
						<?php }  ?>
					</span>

					<span class="by">
						<?php printf( esc_html__( 'Theme: %1$s by %2$s', 'fashiona' ), '<a href="http://www.wp3layouts.com/fashiona-bootstrap-responsive-blog-magazine-wordpress-theme/" target="_blank">Fashiona</a>', '<a href="http://www.wp3layouts.com/" target="_blank">WP3Layouts</a>' ); ?>
					</span>
				</p>
			</div>
		</div>
		
	</div>
</div> <!--#page-wrapper-->
<?php wp_footer(); ?>
</body>
</html>

<?php
 }
