<?php
/**
 * Fashiona WP3 functions and definitions
 *
 * @link http://www.wp3layouts.com
 *
 * @package Fashiona
 */

 
 /*----------------------------------------------
	Admin Options
-----------------------------------------------*/
// Include tgm for recommended plugins
include_once( FASHIONA_WP3_FUNCTIONS_DIRECTORY . '/admin/tgm/tgm-init.php' );

/*------------------------------------------------------*/

if ( ! function_exists( 'fashiona_wp3_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function fashiona_wp3_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Style Blog WP3, use a find and replace
	 * to change 'fashiona' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'fashiona', FASHIONA_WP3_DIRECTORY . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
		add_image_size( 'fashiona-tiny', 120, 90, true );
        add_image_size( 'fashiona-rectangle-size', 380, 260, array('center','top') );
        add_image_size( 'fashiona-single-size', 9999, 620, array('center','top') );



	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'main-menu' => esc_html__( 'Main Menu', 'fashiona' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'fashiona_wp3_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	

	add_theme_support( 'custom-logo', array(                                
		'height'      => 140,
		'width'       => 460,
		'flex-height' => false,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'fashiona_wp3_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function fashiona_wp3_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'fashiona_wp3_content_width', 640 );
}
add_action( 'after_setup_theme', 'fashiona_wp3_content_width', 0 );


// Excerpt Length
function fashiona_wp3_excerpt_length() {
	if ( is_admin() ) 
	{
		return $more;
	}
	if ( get_theme_mod('fashiona_wp3_post_excerpt_length', 30) )
	{
		$more = esc_attr( get_theme_mod('fashiona_wp3_post_excerpt_length', 30) );
	}
	return $more;
}
add_filter( 'excerpt_length', 'fashiona_wp3_excerpt_length', 999 );

// Excerpt More
function fashiona_wp3_excerpt_more( $link ) {
	if ( is_admin() ) 
	{
		return $link;
	}

	if ( get_theme_mod('fashiona_wp3_hide_readmore', true) == true )
	{
		$link = sprintf( '<div class="bht1"><a href="%1$s">%2$s</a></div>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			sprintf( __( '%1$s<span class="screen-reader-text"> "%2$s"</span>', 'fashiona' ), esc_attr( get_theme_mod('fashiona_wp3_text_readmore', 'Read More') ), get_the_title( get_the_ID() ) )
		);
	
		return ' &hellip; ' . $link;
	}
}
add_filter( 'excerpt_more', 'fashiona_wp3_excerpt_more' );



//Display Post Next/Prev buttons if enabled.
function fashiona_wp3_next_prev_post() { ?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<?php 
				previous_post_link( '<div class="nav-previous"> %link</div>', '<i class="fa fa-long-arrow-left" aria-hidden="true"></i>'. __(' Previous Post','fashiona'));
				next_post_link( '<div class="nav-next">%link</div>', __('Next Post ','fashiona'). '<i class="fa fa-long-arrow-right" aria-hidden="true"></i>' );
			?>
		</div><!-- .next_prev_post -->
	</nav>
	<div class="clearfix"></div>
<?php }                 


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function fashiona_wp3_widgets_init() {


	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar 1', 'fashiona' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'fashiona' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widgets Area 1', 'fashiona' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'fashiona' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widgets Area 2', 'fashiona' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'fashiona' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widgets Area 3', 'fashiona' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'fashiona' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

}
add_action( 'widgets_init', 'fashiona_wp3_widgets_init' );

// Move theme 28px to the bottom if admin bar is shown.
function fashiona_wp3_prefix_move_theme_down() {
	if ( is_admin_bar_showing() ) {
		?>
		<style type="text/css" media="screen">
			#wpadminbar {
				clear: both;
				margin-bottom: 20px;
				z-index: 1;
			}
			#navToggle{
				 top: 45px;
			}
		</style>
		<?php
	}
}
add_action( 'wp_head', 'fashiona_wp3_prefix_move_theme_down' );

//Display Author box if enabled.
function fashiona_wp3_author_box() {
	$authorbox = get_theme_mod('fashiona_wp3_hide_single_author_box', true) ? true : false ;
		if ( $authorbox == true ){ 
		?>
			<div class="post-author-box">
				<div class="postauthor">
					<h4><?php esc_html_e('About The Author', 'fashiona'); ?></h4>
					<div class="author-box">
						<?php if(function_exists('get_avatar')) { echo get_avatar( get_the_author_meta('email'), '150' );  } ?>
						<div class="author-box-content">
							<div class="vcard clearfix">
								<a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta( 'ID' ) )); ?>" rel="nofollow" class="fn"><i class="fa fa-user"></i><?php the_author(); ?></a>
							</div>
							<?php if( get_the_author_meta( 'description' ) ) { ?>
								<p><?php the_author_meta('description') ?></p>
							<?php }?>
						</div>
					</div>
				</div>
			</div>	
		<div class="clearfix"></div>			
	<?php }
}                 




